package ru.ulstu.admin.service;

import org.springframework.security.access.annotation.Secured;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import ru.ulstu.admin.model.IndicatorForm;
import ru.ulstu.indicator.model.Course;
import ru.ulstu.indicator.model.Indicator;
import ru.ulstu.model.UserRoleConstants;

@Controller
@RequestMapping("/admin")
@Secured({UserRoleConstants.ADMIN})
public class AdminController {
    private final AdminService adminService;

    public AdminController(AdminService adminService) {
        this.adminService = adminService;
    }

    @GetMapping("indicators")
    public String getListOfIndicators(Model model) {
        model.addAttribute("indicators", adminService.getIndicators());
        return "indicatorsList";
    }

    @GetMapping("/editIndicator/{indicatorId}")
    @Secured({UserRoleConstants.ADMIN})
    public String editIndicator(@PathVariable(value = "indicatorId") Integer id, Model model) {
        model.addAttribute("indicator",
                (id != null && id != 0)
                        ? adminService.getIndicatorById(id)
                        : new Indicator());
        model.addAttribute("courses", Course.values());
        return "editIndicator";
    }

    @PostMapping(value = "saveIndicator", params = "save")
    public String saveIndicator(IndicatorForm indicatorForm, Model model) {
        adminService.saveIndicator(indicatorForm);
        return "redirect:/admin/indicators";
    }

    @PostMapping(value = "saveIndicator", params = "delete")
    public String deleteIndicator(IndicatorForm indicatorForm, Model model) {
        adminService.deleteIndicator(indicatorForm);
        return "redirect:/admin/indicators";
    }
}
